"""Collections of various bits of useful sequence data."""

FREQS = {
    'protein': {
        'A': 0.0826,
        'Q': 0.0393,
        'L': 0.0965,
        'S': 0.0659,
        'R': 0.0553,
        'E': 0.0674,
        'K': 0.0583,
        'T': 0.0534,
        'N': 0.0406,
        'G': 0.0708,
        'M': 0.0241,
        'W': 0.0109,
        'D': 0.0546,
        'H': 0.0227,
        'F': 0.0386,
        'Y': 0.0292,
        'C': 0.0137,
        'I': 0.0594,
        'P': 0.0471,
        'V': 0.0687,
        'X': 1,
        'B': 0.0406 + 0.0546,
        'Z': 0.0393 + 0.0674
    },
    'dna': {
        'A': 0.25,
        'C': 0.25,
        'G': 0.25,
        'T': 0.25
    },
    'rna': {
        'A': 0.25,
        'C': 0.25,
        'G': 0.25,
        'U': 0.25
    }
}

WEIGHTS = {
    'protein': {
        'A': 1.2106537530266344,
        'C': 7.299270072992702,
        'E': 1.4836795252225519,
        'D': 1.8315018315018312,
        'G': 1.4124293785310733,
        'F': 2.590673575129534,
        'I': 1.6835016835016834,
        'H': 4.405286343612334,
        'K': 1.7152658662092626,
        'M': 4.149377593360996,
        'L': 1.0362694300518134,
        'N': 2.4630541871921183,
        'Q': 2.5445292620865136,
        'P': 2.123142250530785,
        'S': 1.5174506828528072,
        'R': 1.8083182640144662,
        'T': 1.8726591760299625,
        'W': 9.174311926605505,
        'V': 1.4556040756914121,
        'Y': 3.4246575342465753
    },
    'dna': {
        'A': 1,
        'C': 1,
        'G': 1,
        'T': 1
    },
    'rna': {
        'A': 1,
        'C': 1,
        'G': 1,
        'U': 1
    }

}


ALPHABET = {
    'dna': 'ATGC',
    'protein': 'ACDEFGHIKLMNPQRSTVWY'
}

REDUCED_ALPHABET = {
    'dna': {
        'A': 'R',
        'G': 'R',
        'T': 'Y',
        'C': 'Y'
    },
    'protein': {
        'T': 'S',
        'E': 'D',
        'Q': 'K',
        'R': 'K',
        'V': 'I',
        'L': 'I',
        'M': 'I',
        'W': 'F',
        'Y': 'F'
    }
}


def get_alphabet(mol):
    return ALPHABET[mol]


def get_freqs(mol):
    return FREQS[mol]


def get_weights(mol):
    return WEIGHTS[mol]


def get_reduced_alphabet(mol):
    return REDUCED_ALPHABET[mol]
